import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { G as GetEventsViewResponse, E as EventsViewExtendedEnvelope, a as EventsViewProjectionUpdatedEnvelope } from './calendar-v3-events-view-event-views.universal-Br3DvpnA.mjs';
export { J as ActionEvent, Q as BaseEventMetadata, p as CommonIdentificationData, q as CommonIdentificationDataIdOneOf, C as ConferencingDetails, D as Day, x as DomainEvent, y as DomainEventBodyOneOf, K as Empty, z as EntityCreatedEvent, H as EntityDeletedEvent, B as EntityUpdatedEvent, i as Event, h as EventAddedOrUpdated, U as EventMetadata, s as EventRemoved, e as EventsView, t as EventsViewExtended, f as EventsViewProjectionUpdated, g as EventsViewProjectionUpdatedTypeOneOf, v as ExtendEventsViewRequest, w as ExtendEventsViewResponse, r as ExtendedFields, d as Field, F as Frequency, u as GetEventsViewRequest, N as IdentificationData, O as IdentificationDataIdOneOf, I as IdentityType, k as Location, L as LocationType, M as MessageEnvelope, n as Participant, m as Participants, P as ParticipantsStatus, o as Permission, j as RecurrenceRule, R as RecurrenceType, l as Resource, A as RestoreInfo, b as Role, S as Status, T as Transparency, c as Type, W as WebhookIdentityType, Z as ZonedDate } from './calendar-v3-events-view-event-views.universal-Br3DvpnA.mjs';

declare function getEventsView$1(httpClient: HttpClient): GetEventsViewSignature;
interface GetEventsViewSignature {
    /**
     * Doesn’t return details about events within the view. You can use
     * [queryEvents()](https://dev.wix.com/docs/sdk/backend-modules/calendar/events/query-events),
     * providing `eventsView.endDate` as `toLocalDate` to retrieve the
     * events.
     */
    (): Promise<GetEventsViewResponse>;
}
declare const onEventsViewExtended$1: EventDefinition<EventsViewExtendedEnvelope, "wix.calendar.v3.events_view_extended">;
declare const onEventsViewProjectionUpdated$1: EventDefinition<EventsViewProjectionUpdatedEnvelope, "wix.calendar.v3.events_view_projection_updated">;

declare const getEventsView: MaybeContext<BuildRESTFunction<typeof getEventsView$1> & typeof getEventsView$1>;
/**
 * Triggered when the current event view is extended.
 *
 *
 * Doesn’t include details about existing events added to the view due to the
 * extension. To receive updates about those events, subscribe to
 * [Events View Projection Updated](https://dev.wix.com/docs/rest/business-management/calendar/event-views-v3/events-view-projection-updated).
 *
 * The event view is periodically extended by Wix Calendars, you can't manually
 * extend it.
 */
declare const onEventsViewExtended: BuildEventDefinition<typeof onEventsViewExtended$1>;
/**
 * Triggered when an [event](https://dev.wix.com/docs/rest/business-management/calendar/events-v3/introduction)
 * is added to, removed from, or updated within the current event view. This includes cases when:
 * + A new event is created within the view.
 * + An existing event within the view is updated, including when it's rescheduled to start outside the view.
 * + An event within the view is deleted.
 * + An event previously outside the view is rescheduled to fall within it.
 * + The view is extended, bringing an existing event into scope.
 */
declare const onEventsViewProjectionUpdated: BuildEventDefinition<typeof onEventsViewProjectionUpdated$1>;

export { EventsViewExtendedEnvelope, EventsViewProjectionUpdatedEnvelope, GetEventsViewResponse, getEventsView, onEventsViewExtended, onEventsViewProjectionUpdated };
